<?php

/**
 * @file
 *
 * Provides the HTML and XML Classes for Feeds KML Parser.
 */

/**
 * Base class for the HTML and XML parsers.
 */
class FeedsParserKML extends FeedsParser {
  /**  
   * Implementation of FeedsParser::parse().  
   */
  public function parse(FeedsImportBatch $batch, FeedsSource $source) {
    $raw = trim($batch->getRaw());  

    if (empty($raw)) {
      drupal_set_message(t('Feeds KML parser: The XML document is empty.'), 'warning');
      return;
    }

    $xml = new SimpleXMLElement($raw);
    $xml_ns = $xml->getNamespaces();
    $xml->registerXPathNamespace('k', current($xml_ns));
    foreach ($xml->xpath('//k:Placemark') as $placemark) {
      if (isset($placemark->Point)) {
        $coordinates = explode(',', $placemark->Point->coordinates);
        $item = array(
          'name' => (string) $placemark->name,
          'description' => (string) $placemark->description,
          'longitude' => $coordinates[0],
          'latitude' => $coordinates[1],
        );
        
        if (module_exists('openlayers_cck')) {
          $item['openlayers_wkt'] = "GEOMETRYCOLLECTION(POINT(${coordinates[0]} ${coordinates[1]}))";
        }

        $batch->items[] = $item;
      }
    }
  }

  /**
   * Return mapping sources.
   *
   * At a future point, we could expose data type information here,
   * storage systems like Data module could use this information to store
   * parsed data automatically in fields with a correct field type.
   */
  public function getMappingSources() {
    $sources = array(
      'name' => array(
        'name' => t('Name'),
        'description' => t('Location name.'),
      ),
      'description' => array(
        'name' => t('Description'),
        'description' => t('Location description.'),
      ),
      'longitude' => array(
        'name' => t('Longitude'),
        'description' => t('Longitude coordinates of the location in text format.'),
      ),
      'latitude' => array(
        'name' => t('Latitude'),
        'description' => t('Latitude coordinates of the location in text format.'),
      ),
    );
    if (module_exists('openlayers_cck')) {
      $sources['openlayers_wkt'] = array(
        'name' => t('OpenLayers WKT'),
        'description' => t('Location coordinates in OpenLayers WKT format.'),
      );
    }
    return $sources + parent::getMappingSources();
  }
}
